<?php
/**
 * @copyright (c) JTL-Software-GmbH
 * @license http://jtl-url.de/jtlshoplicense
 */

/** @global Plugin $oPlugin */
if (isset($oPlugin->oPluginEinstellungAssoc_arr['hb_nutzen']) &&
    $oPlugin->oPluginEinstellungAssoc_arr['hb_nutzen'] === 'Y' &&
    strlen($oPlugin->oPluginEinstellungAssoc_arr['hb_token']) > 0
) {
	/** Document Id's
	"12766C46A8A":"AGBs",
	"12766C53647":"Widerrufsbelehrung",
	"1452C24576D":"Widerrufsbelehrung digitale Waren",
	"1463C5DBF05":"Widerrufsbelehrung Dienstleistungen",
	"12766C58F26":"Zahlung und Versand",
	"160DEDA9674":"Datenschutzerklärung",
	"1293C20B491":"Impressum",
	"134CBB4D101":"Batteriehinweise"
	**/
    define('HB_LOGGING', 0); // Logging, 1 = true, 0 = false
    define('HB_LOGGING_FILE', PFAD_LOGFILES . 'haendlerbund.log'); // Logging
    define('HB_TYPE_AGB', '12766C46A8A');	// AGB
    define('HB_TYPE_WRB', '12766C53647');	// WRB
    define('HB_TYPE_IMP', '1293C20B491');	// Impressum
    define('HB_TYPE_DAT', '12766C5E204');	// Datenschutz ???
    define('HB_TYPE_BAT', '134CBB4D101');	// Batterie
	define('HB_TYPE_PAY', '12766C58F26');  	// Zahlung und Versand
    define('HB_FORMAT_HTML', 'html');
    define('HB_FORMAT_TEXT', 'txt');
    define('HB_URL', 'https://www.hb-intern.de/www/hbm/api/live_rechtstexte.htm');

    $nCaching = (int)$oPlugin->oPluginEinstellungAssoc_arr['hb_intervall']; // Hours
    if ($nCaching < 1) {
        $nCaching = 24;
    }
    checkHaendlerbund($oPlugin, $nCaching);
}

/**
 * @param Plugin $oPlugin
 * @param string $cType
 * @param string $cFormat
 * @param int    $kUpdate
 * @param int    $kSprache
 * @return bool
 */
function getNewHaendlerbund($oPlugin, $cType, $cFormat, $kUpdate, $kSprache)
{
    Jtllog::writeLog(
        'Conny Update: kUpdate (haendlerbund) ' . $kUpdate . ' - cType ' .
            $cType . ' - kSprache ' . $kSprache . ' wird geladen ...',
        JTLLOG_LEVEL_DEBUG,
        false,
        'kPlugin',
        $oPlugin->kPlugin
    );
	
    // Sprache definieren
	if ($kSprache == 1) {
		$cLang = "";
	} elseif ($kSprache == 2) {
		$cLang = "en";
	} else {
		$cLang = "";
	}
	
	// WRB id umschreiben wenn anderer Text geholt werden muss, z.B. digitale Waren oder Dienstleistungen
	$cId_Type = $cType;
	if (isset($oPlugin->oPluginEinstellungAssoc_arr['hb_akt_wrb']) && $cId_Type === "12766C53647") {
		switch ($oPlugin->oPluginEinstellungAssoc_arr['hb_akt_wrb']) {
            // normale WRB
            case 'WRB1':
				$cId_Type = '12766C53647';
				break;

            // digital WRB
            case 'WRB2':
				$cId_Type = '1452C24576D';
				break;
			
			// digital Dienstleistung
            case 'WRB3':
				$cId_Type = '1463C5DBF05';
				break;
		}
	}
		
		
	// Parameter für URL zusammenfügen
    $cParams  = http_build_query([
        'APIkey'      => '1IqJF0ap6GdDNF7HKzhFyciibdml8t4v',
        'AccessToken' => $oPlugin->oPluginEinstellungAssoc_arr['hb_token'],
        'mode'        => $cFormat === 'html' ? 'classes' : 'plain',
        'did'         => $cId_Type,
		'lang'		  => $cLang
    ], '', '&');
    $cURL     = HB_URL . '?' . $cParams;
	// $cContent = @http_get_contents($cURL);
	$cContent = file_get_contents($cURL);
    $cContent = utf8_decode($cContent);
	
	// Fehlerprüfung
    if (in_array($cContent, ['DOCUMENT_NOT_AVAILABLE', 'SHOP_NOT_FOUND', 'WRONG_API_KEY'], true)) {
        Jtllog::writeLog('Fehler (haendlerbund): ' . $cContent, JTLLOG_LEVEL_ERROR, false, 'kPlugin', $oPlugin->kPlugin);
        $cContent = false;
    }
    // Wurde ein Text uebermittelt?
    if (empty($cContent)) {
        Jtllog::writeLog(
            "Fehler (haendlerbund): " . "Kein Inhalt fuer {$cType}, {$cFormat} vorhanden.",
            JTLLOG_LEVEL_ERROR,
            false,
            'kPlugin',
            $oPlugin->kPlugin
        );
        $cContent = false;
    }

    if ($cContent !== false) {
        $cContent = Shop::DB()->escape($cContent);
        $cSpalte  = '';
        $cTabelle = '';
        $cWhere   = '';
        switch ($cType) {
            // AGB
            case HB_TYPE_AGB:
				if (isset($oPlugin->oPluginEinstellungAssoc_arr['hb_akt_agb']) &&
					$oPlugin->oPluginEinstellungAssoc_arr['hb_akt_agb'] === 'Y') {
					$cSpalte  = "cAGBContentHtml";
					$cTabelle = "ttext";
					$cWhere   = " kSprache = " . (int)$kSprache;
					if ($cFormat === HB_FORMAT_TEXT) {
						// $cContent = strip_tags($cContent);
						$cSpalte = "cAGBContentText";
					}
				}
                break;

            // WRB
            case HB_TYPE_WRB:
				if (isset($oPlugin->oPluginEinstellungAssoc_arr['hb_akt_wrb']) &&
					$oPlugin->oPluginEinstellungAssoc_arr['hb_akt_wrb'] === 'WRB1')	{
					$cSpalte  = "cWRBContentHtml";
					$cTabelle = "ttext";
					$cWhere   = " kSprache = " . (int)$kSprache;
					if ($cFormat === HB_FORMAT_TEXT) {
						// $cContent = strip_tags($cContent);
						$cSpalte = "cWRBContentText";
					}
				}
                break;

            // Impressum
            case HB_TYPE_IMP:
				if (isset($oPlugin->oPluginEinstellungAssoc_arr['hb_akt_imp']) &&
					$oPlugin->oPluginEinstellungAssoc_arr['hb_akt_imp'] === 'Y') {
					$cSpalte  = "cContent";
					$cTabelle = "tlinksprache";
					$oLink    = Shop::DB()->query("SELECT kLink FROM tlink WHERE nLinkart = " . LINKTYP_IMPRESSUM, 1);
					$cWhere   = "cISOSprache = '" . gibSprachKeyISO("", $kSprache) . "' AND kLink = " . $oLink->kLink;
				}
                break;

            // Datenschutz
            case HB_TYPE_DAT:
				if (isset($oPlugin->oPluginEinstellungAssoc_arr['hb_akt_dat']) &&
					$oPlugin->oPluginEinstellungAssoc_arr['hb_akt_dat'] === 'Y') {
					$cSpalte  = "cContent";
					$cTabelle = "tlinksprache";
					$oLink    = Shop::DB()->query("SELECT kLink FROM tlink WHERE nLinkart = " . LINKTYP_DATENSCHUTZ, 1);
					$cWhere   = "cISOSprache = '" . gibSprachKeyISO("", $kSprache) . "' AND kLink = " . $oLink->kLink;
				}
                break;

            // Batteriegesetzhinweise
            case HB_TYPE_BAT:
				if (isset($oPlugin->oPluginEinstellungAssoc_arr['hb_akt_bat']) &&
					$oPlugin->oPluginEinstellungAssoc_arr['hb_akt_bat'] === 'Y') {
					$cSpalte  = "cContent";
					$cTabelle = "tlinksprache";
					$oLink    = Shop::DB()->query("SELECT kLink FROM tlink WHERE nLinkart = " . LINKTYP_BATTERIEGESETZ_HINWEISE, 1);
					$cWhere   = "cISOSprache = '" . gibSprachKeyISO("", $kSprache) . "' AND kLink = " . $oLink->kLink;
				}
                break;
				
			// Zahlung und Versand
            case HB_TYPE_PAY:
				if (isset($oPlugin->oPluginEinstellungAssoc_arr['hb_akt_zuv']) &&
					$oPlugin->oPluginEinstellungAssoc_arr['hb_akt_zuv'] === 'Y') {
					$cSpalte  = "cContent";
					$cTabelle = "tlinksprache";
					$oLink    = Shop::DB()->query("SELECT kLink FROM tlink WHERE nLinkart = " . LINKTYP_VERSAND, 1);
					$cWhere   = "cISOSprache = '" . gibSprachKeyISO("", $kSprache) . "' AND kLink = " . $oLink->kLink;
				}
                break;	
        }
		
		// Signatur schreiben
		if (isset($oPlugin->oPluginEinstellungAssoc_arr['hb_signature']) &&
				$oPlugin->oPluginEinstellungAssoc_arr['hb_signature'] === 'Y'){
			if ($cFormat === HB_FORMAT_TEXT) {
				$cContent = $cContent."\n\rSignatur: ".date("dmyHi");
			} else {
				$cContent = $cContent."<br><small>Signatur: ".date("dmyHi")."</small><br>";
			}
		}
		
		// CSS schreiben
		if (isset($oPlugin->oPluginEinstellungAssoc_arr['hb_css_include']) &&
				$oPlugin->oPluginEinstellungAssoc_arr['hb_css_include'] === 'Y' && $cFormat <> HB_FORMAT_TEXT){
			if ( isset($oPlugin->oPluginEinstellungAssoc_arr['hb_css']) &&
				!empty($oPlugin->oPluginEinstellungAssoc_arr['hb_css']) && $cFormat <> HB_FORMAT_TEXT ){
				$cContent = "<style>".$oPlugin->oPluginEinstellungAssoc_arr['hb_css']."</style>".$cContent;
			}
		}
		
		// Datenbank updaten
        Shop::DB()->query("
                UPDATE " . $cTabelle . "
                    SET " . $cSpalte . " = '" . $cContent . "'
                    WHERE " . $cWhere, 3
        );
        Shop::DB()->query("
                UPDATE xplugin_jtl_haendlerbund_tupdate
                    SET dAktualisiert = now(), nVersuch = 0
                    WHERE kUpdate = " . (int)$kUpdate, 3
        );
        Jtllog::writeLog(
            '(haendlerbund) kUpdate: ' . $kUpdate . ' ' . $cType . ' wurde aktualisiert.',
            JTLLOG_LEVEL_DEBUG,
            false,
            'kPlugin',
            $oPlugin->kPlugin
        );
        
        return true;
    } else {
        Shop::DB()->query("
                UPDATE xplugin_jtl_haendlerbund_tupdate
                    SET nVersuch = nVersuch + 1
                    WHERE kUpdate = " . (int)$kUpdate, 3
        );
        Jtllog::writeLog(
            '(haendlerbund) kUpdate ' . $kUpdate . ' war nicht erfolgreich.',
            JTLLOG_LEVEL_ERROR,
            false,
            'kPlugin',
            $oPlugin->kPlugin
        );
    }
    
    return false;
}



/**
 * Prueft ob DB noch aktuell ist
 *
 * @param Plugin $oPlugin
 * @param int $nCaching
 */
function checkHaendlerbund($oPlugin, $nCaching)
{
    $oLatestTry = Shop::DB()->query("SELECT * FROM xplugin_jtl_haendlerbund_tupdate ORDER BY dVersuch DESC LIMIT 1", 1);
    $nDelay     = pow($oLatestTry->nVersuch, 2) * 60;
    if($nDelay > 86400) {
        $nDelay = 86400;  
    }
    $time = strtotime($oLatestTry->dVersuch);
    if ($time + $nDelay > time()) {
        Jtllog::writeLog(
            '(haendlerbund) Aktualisierung pausiert aufgrund von Fehlern beim letzten Abruf. ' .
            'N&auml;chste Aktualisierung fr&uuml;hstens '.  date('d.m.Y H:i:s', $time + $nDelay),
            JTLLOG_LEVEL_DEBUG,
            false,
            'kPlugin',
            $oPlugin->kPlugin
        );
        return;
    }    
    
    $oSprache = Shop::DB()->query("
            SELECT kSprache
                FROM tsprache
                WHERE cISO = 'ger' ", 1
    );

    if (isset($oSprache->kSprache) && $oSprache->kSprache > 0) {
        $oUpdate_arr = Shop::DB()->query("
            SELECT *
                FROM xplugin_jtl_haendlerbund_tupdate
                WHERE (dAktualisiert = '0000-00-00 00:00:00'
                    OR DATE_ADD(dAktualisiert, INTERVAL " . (int)$nCaching . " HOUR) < now())
                    AND nAktiv = 1", 2
        );
        Jtllog::writeLog(
            '(haendlerbund) Text: ' . print_r($oUpdate_arr, true),
            JTLLOG_LEVEL_DEBUG,
            false,
            'kPlugin',
            $oPlugin->kPlugin
        );

        if (count($oUpdate_arr) > 0) {
            foreach ($oUpdate_arr as $oUpdate) {
                if (isset($oUpdate->kUpdate) && $oUpdate->kUpdate > 0) {
                    if (isset($oUpdate->nVersuch) && $oUpdate->nVersuch >= 999) {
                        Shop::DB()->query("
                            UPDATE xplugin_jtl_haendlerbund_tupdate
                                SET nAktiv = 0
                                WHERE kUpdate = " . (int)$oUpdate->kUpdate, 3
                        );
                        Jtllog::writeLog(
                            'kUpdate (haendlerbund) ' . $oUpdate->kUpdate . ' wurde deaktiviert!',
                            JTLLOG_LEVEL_ERROR,
                            true,
                            'kPlugin',
                            $oPlugin->kPlugin
                        );

                        continue;
                    }
                    
                    // $nDelay
                    Shop::DB()->query("
                        UPDATE xplugin_jtl_haendlerbund_tupdate 
                            SET dVersuch = NOW() 
                            WHERE kUpdate = " . (int)$oUpdate->kUpdate, 3
                    );
					
					// Update englisch
					if (isset($oPlugin->oPluginEinstellungAssoc_arr['hb_lang_en']) &&
						$oPlugin->oPluginEinstellungAssoc_arr['hb_lang_en'] === 'Y'){
						getNewHaendlerbund(
							$oPlugin,
							$oUpdate->cType,
							$oUpdate->cFormat,
							$oUpdate->kUpdate,
							2
						);
					}

                    // Updaten deutsch
					if (isset($oPlugin->oPluginEinstellungAssoc_arr['hb_lang_de']) &&
						$oPlugin->oPluginEinstellungAssoc_arr['hb_lang_en'] === 'Y'){
						if (!getNewHaendlerbund(
							$oPlugin,
							$oUpdate->cType,
							$oUpdate->cFormat,
							$oUpdate->kUpdate,
							$oSprache->kSprache
						)) {
							break;
						}
					}
                }
            }
        }
    }
}
